@@ -35,9 +35,9 @@ class Selenium(Scraper):
         LOGGER.setLevel(logging.WARNING)
 
         if platform.system() == 'Windows':
-            self.driver = webdriver.Chrome('../drivers/windows_chromedriver.exe', options=options)
+            self.driver = webdriver.Chrome('../drivers/chromedriver.exe', options=options)
         if platform.system() == 'Linux':
-            self.driver = webdriver.Chrome('../drivers/linux_chromedriver', options=options)
+            self.driver = webdriver.Chrome('../drivers/chromedriver', options=options)
         
         self.handles = {}
 
